library(testthat)
library(sjPlot)
library(sjmisc)
data(efc)

test_check("sjPlot")
